# A python module for audio and music processing

# baseZhang
[![baseZhang](https://img.shields.io/pypi/v/baseZhang.svg)](https://pypi.python.org/pypi/baseZhang)
[![baseZhang](https://img.shields.io/pypi/dm/baseZhang.svg "PyPi Downloads")](https://pypi.python.org/pypi/baseZhang)

# @mac

1. Install Homebrew
    /usr/bin/ruby -e "$(curl -fsSL https://raw.githubusercontent.com/Homebrew/install/master/install)"
2. install portaudio
    brew install portaudio
3. install pyaudio
    pip install pyaudio
4. use pip install baseZhang

# @windows

1. choose python 2.7.13 and pls use the X86 not the X86-X64 installer package.
2. install [scipy](https://sourceforge.net/projects/scipy/files/scipy/0.16.1/) by the 32bit installer package of exe.
3. change backend from tensorflow to theano
    search your file system and find the keras.json file. change the contends from tensorflow to theano.
4. download and install ffmpeg from ffmpeg.org
5. use  pip install baseZhang


 